@@ -6,36 +6,50 @@ a specific time period: we don't want to see the entries from before some period
 of time, so we fold them into a single transaction per account that has the sum
 total amount of that account.
 """
-__copyright__ = "Copyright (C) 2013-2017  Martin Blais"
+
+from __future__ import annotations
+
+__copyright__ = "Copyright (C) 2013-2017, 2019-2021, 2023-2024  Martin Blais"
 __license__ = "GNU GPLv2"
 
-import datetime
 import collections
+import datetime
+from typing import TYPE_CHECKING
+from typing import Callable
 
-from beancount.core.number import ZERO
-from beancount.core.data import Transaction
-from beancount.core.data import Open
-from beancount.core.data import Close
-from beancount.core.account_types import is_income_statement_account
 from beancount.core import amount
-from beancount.core import inventory
+from beancount.core import convert
 from beancount.core import data
 from beancount.core import flags
 from beancount.core import getters
 from beancount.core import interpolate
-from beancount.core import convert
+from beancount.core import inventory
 from beancount.core import prices
-from beancount.utils import bisect_key
+from beancount.core.account_types import is_income_statement_account
+from beancount.core.data import Close
+from beancount.core.data import Open
+from beancount.core.data import Transaction
+from beancount.core.number import ZERO
 from beancount.parser import options
+from beancount.utils import bisect_key
+
+if TYPE_CHECKING:
+    from beancount.core.account import Account
+    from beancount.core.account_types import AccountTypes
+    from beancount.core.data import Currency
+    from beancount.core.data import Directives
+    from beancount.loader import OptionsMap
 
 
-def open(entries,
-         date,
-         account_types,
-         conversion_currency,
-         account_earnings,
-         account_opening,
-         account_conversions):
+def open(
+    entries: Directives,
+    date: datetime.date,
+    account_types: AccountTypes,
+    conversion_currency: Currency,
+    account_earnings: Account,
+    account_opening: Account,
+    account_conversions: Account,
+) -> tuple[Directives, int]:
     """Summarize entries before a date and transfer income/expenses to equity.
 
     This method essentially prepares a list of directives to contain only
@@ -96,10 +110,12 @@ def open(entries,
     return entries, index
 
 
-def close(entries,
-          date,
-          conversion_currency,
-          account_conversions):
+def close(
+    entries: Directives,
+    date: datetime.date,
+    conversion_currency: Currency,
+    account_conversions: Account,
+) -> tuple[Directives, int]:
     """Truncate entries that occur after a particular date and ensure balance.
 
     This method essentially removes entries after a date. It truncates the
@@ -145,10 +161,12 @@ def close(entries,
 
 
 # TODO(blais): This needs to be renamed in v3. Long name. Not obvious enough.
-def clear(entries,
-          date,
-          account_types,
-          account_earnings):
+def clear(
+    entries: Directives,
+    date: datetime.date,
+    account_types: AccountTypes,
+    account_earnings: Account,
+) -> tuple[Directives, int]:
     """Transfer income and expenses balances at the given date to the equity accounts.
 
     This method insert entries to zero out balances on income and expenses
@@ -170,44 +188,54 @@ def clear(entries,
     index = len(entries)
 
     # Transfer income and expenses before the period to equity.
-    income_statement_account_pred = (
-        lambda account: is_income_statement_account(account, account_types))
-    new_entries = transfer_balances(entries, date,
-                                    income_statement_account_pred, account_earnings)
+    income_statement_account_pred = lambda account: is_income_statement_account(
+        account, account_types
+    )
+    new_entries = transfer_balances(
+        entries, date, income_statement_account_pred, account_earnings
+    )
 
     return new_entries, index
 
 
-def open_opt(entries, date, options_map):
-    """Convenience function to open() using an options map.
-    """
+def open_opt(
+    entries: Directives, date: datetime.date, options_map: OptionsMap
+) -> tuple[Directives, int]:
+    """Convenience function to open() using an options map."""
     account_types = options.get_account_types(options_map)
     previous_accounts = options.get_previous_accounts(options_map)
-    conversion_currency = options_map['conversion_currency']
+    conversion_currency = options_map["conversion_currency"]
     return open(entries, date, account_types, conversion_currency, *previous_accounts)
 
-def close_opt(entries, date, options_map):
-    """Convenience function to close() using an options map.
-    """
-    conversion_currency = options_map['conversion_currency']
+
+def close_opt(
+    entries: Directives, date: datetime.date, options_map: OptionsMap
+) -> tuple[Directives, int]:
+    """Convenience function to close() using an options map."""
+    conversion_currency = options_map["conversion_currency"]
     current_accounts = options.get_current_accounts(options_map)
     return close(entries, date, conversion_currency, current_accounts[1])
 
-def clear_opt(entries, date, options_map):
-    """Convenience function to clear() using an options map.
-    """
+
+def clear_opt(
+    entries: Directives, date: datetime.date, options_map: OptionsMap
+) -> tuple[Directives, int]:
+    """Convenience function to clear() using an options map."""
     account_types = options.get_account_types(options_map)
     current_accounts = options.get_current_accounts(options_map)
     return clear(entries, date, account_types, current_accounts[0])
 
 
-def clamp(entries,
-          begin_date, end_date,
-          account_types,
-          conversion_currency,
-          account_earnings,
-          account_opening,
-          account_conversions):
+def clamp(
+    entries: Directives,
+    begin_date: datetime.date,
+    end_date: datetime.date,
+    account_types: AccountTypes,
+    conversion_currency: Currency,
+    account_earnings: Account,
+    account_opening: Account,
+    account_conversions: Account,
+):
     """Filter entries to include only those during a specified time period.
 
     Firstly, this method will transfer all balances for the income and expense
@@ -247,10 +275,12 @@ def clamp(entries,
       sheet fed with only the summarized entries.
     """
     # Transfer income and expenses before the period to equity.
-    income_statement_account_pred = (
-        lambda account: is_income_statement_account(account, account_types))
-    entries = transfer_balances(entries, begin_date,
-                                income_statement_account_pred, account_earnings)
+    income_statement_account_pred = lambda account: is_income_statement_account(
+        account, account_types
+    )
+    entries = transfer_balances(
+        entries, begin_date, income_statement_account_pred, account_earnings
+    )
 
     # Summarize all the previous balances, after transferring the income and
     # expense balances, so all entries for those accounts before the begin date
@@ -266,7 +296,12 @@ def clamp(entries,
     return entries, index
 
 
-def clamp_opt(entries, begin_date, end_date, options_map):
+def clamp_opt(
+    entries: Directives,
+    begin_date: datetime.date,
+    end_date: datetime.date,
+    options_map: OptionsMap,
+) -> tuple[Directives, int]:
     """Clamp by getting all the parameters from an options map.
 
     See clamp() for details.
@@ -283,20 +318,26 @@ def clamp_opt(entries, begin_date, end_date, options_map):
     previous_earnings, previous_balances, _ = options.get_previous_accounts(options_map)
     _, current_conversions = options.get_current_accounts(options_map)
 
-    conversion_currency = options_map['conversion_currency']
-    return clamp(entries, begin_date, end_date,
-                 account_types,
-                 conversion_currency,
-                 previous_earnings,
-                 previous_balances,
-                 current_conversions)
-
-
-def cap(entries,
+    conversion_currency = options_map["conversion_currency"]
+    return clamp(
+        entries,
+        begin_date,
+        end_date,
         account_types,
         conversion_currency,
-        account_earnings,
-        account_conversions):
+        previous_earnings,
+        previous_balances,
+        current_conversions,
+    )
+
+
+def cap(
+    entries: Directives,
+    account_types: AccountTypes,
+    conversion_currency: Currency,
+    account_earnings: Account,
+    account_conversions: Account,
+) -> Directives:
     """Transfer net income to equity and insert a final conversion entry.
 
     This is used to move and nullify balances from the income and expense
@@ -319,11 +360,12 @@ def cap(entries,
 
     # Transfer the balances of income and expense accounts as earnings / net
     # income.
-    income_statement_account_pred = (
-        lambda account: is_income_statement_account(account, account_types))
-    entries = transfer_balances(entries, None,
-                                income_statement_account_pred,
-                                account_earnings)
+    income_statement_account_pred = lambda account: is_income_statement_account(
+        account, account_types
+    )
+    entries = transfer_balances(
+        entries, None, income_statement_account_pred, account_earnings
+    )
 
     # Insert final conversion entries.
     entries = conversions(entries, account_conversions, conversion_currency, None)
@@ -331,7 +373,7 @@ def cap(entries,
     return entries
 
 
-def cap_opt(entries, options_map):
+def cap_opt(entries: Directives, options_map: OptionsMap) -> Directives:
     """Close by getting all the parameters from an options map.
 
     See cap() for details.
@@ -344,14 +386,16 @@ def cap_opt(entries, options_map):
     """
     account_types = options.get_account_types(options_map)
     current_accounts = options.get_current_accounts(options_map)
-    conversion_currency = options_map['conversion_currency']
-    return cap(entries,
-               account_types,
-               conversion_currency,
-               *current_accounts)
+    conversion_currency = options_map["conversion_currency"]
+    return cap(entries, account_types, conversion_currency, *current_accounts)
 
 
-def transfer_balances(entries, date, account_pred, transfer_account):
+def transfer_balances(
+    entries: Directives,
+    date: datetime.date | None,
+    account_pred: Callable[[Account], bool],
+    transfer_account: Account,
+) -> Directives:
     """Synthesize transactions to transfer balances from some accounts at a given date.
 
     For all accounts that match the 'account_pred' predicate, create new entries
@@ -383,9 +427,9 @@ def transfer_balances(entries, date, account_pred, transfer_account):
     balances, index = balance_by_account(entries, date)
 
     # Filter out to keep only the accounts we want.
-    transfer_balances = {account: balance
-                         for account, balance in balances.items()
-                         if account_pred(account)}
+    transfer_balances = {
+        account: balance for account, balance in balances.items() if account_pred(account)
+    }
 
     # We need to insert the entries at the end of the previous day.
     if date:
@@ -395,22 +439,30 @@ def transfer_balances(entries, date, account_pred, transfer_account):
 
     # Create transfer entries.
     transfer_entries = create_entries_from_balances(
-        transfer_balances, transfer_date, transfer_account, False,
-        data.new_metadata('<transfer_balances>', 0), flags.FLAG_TRANSFER,
-        "Transfer balance for '{account}' (Transfer balance)")
+        transfer_balances,
+        transfer_date,
+        transfer_account,
+        False,
+        data.new_metadata("<transfer_balances>", 0),
+        flags.FLAG_TRANSFER,
+        "Transfer balance for '{account}' (Transfer balance)",
+    )
 
     # Remove balance assertions that occur after a transfer on an account that
     # has been transferred away; they would break.
-    after_entries = [entry
-                     for entry in entries[index:]
-                     if not (isinstance(entry, data.Balance) and
-                             entry.account in transfer_balances)]
+    after_entries = [
+        entry
+        for entry in entries[index:]
+        if not (isinstance(entry, data.Balance) and entry.account in transfer_balances)
+    ]
 
     # Split the new entries in a new list.
-    return (entries[:index] + transfer_entries + after_entries)
+    return entries[:index] + transfer_entries + after_entries
 
 
-def summarize(entries, date, account_opening):
+def summarize(
+    entries: Directives, date: datetime.date, account_opening: Account
+) -> tuple[Directives, int]:
     """Summarize all entries before a date by replacing then with summarization entries.
 
     This function replaces the transactions up to (and not including) the given
@@ -441,9 +493,14 @@ def summarize(entries, date, account_opening):
 
     # Create summarization / opening balance entries.
     summarizing_entries = create_entries_from_balances(
-        balances, summarize_date, account_opening, True,
-        data.new_metadata('<summarize>', 0), flags.FLAG_SUMMARIZE,
-        "Opening balance for '{account}' (Summarization)")
+        balances,
+        summarize_date,
+        account_opening,
+        True,
+        data.new_metadata("<summarize>", 0),
+        flags.FLAG_SUMMARIZE,
+        "Opening balance for '{account}' (Summarization)",
+    )
 
     # Insert the last price entry for each commodity from before the date.
     price_entries = prices.get_last_price_entries(entries, date)
@@ -452,8 +509,9 @@ def summarize(entries, date, account_opening):
     open_entries = get_open_entries(entries, date)
 
     # Compute entries before the date and preserve the entries after the date.
-    before_entries = sorted(open_entries + price_entries + summarizing_entries,
-                            key=data.entry_sortkey)
+    before_entries = sorted(
+        open_entries + price_entries + summarizing_entries, key=data.entry_sortkey
+    )
     after_entries = entries[index:]
 
     # Return a new list of entries and the index that points after the entries
@@ -461,7 +519,12 @@ def summarize(entries, date, account_opening):
     return (before_entries + after_entries), len(before_entries)
 
 
-def conversions(entries, conversion_account, conversion_currency, date=None):
+def conversions(
+    entries: Directives,
+    conversion_account: Account,
+    conversion_currency: Currency,
+    date: datetime.date | None = None,
+) -> Directives:
     """Insert a conversion entry at date 'date' at the given account.
 
     Args:
@@ -492,10 +555,18 @@ def conversions(entries, conversion_account, conversion_currency, date=None):
         index = len(entries)
         last_date = entries[-1].date
 
-    meta = data.new_metadata('<conversions>', -1)
-    narration = 'Conversion for {}'.format(conversion_balance)
-    conversion_entry = Transaction(meta, last_date, flags.FLAG_CONVERSIONS,
-                                   None, narration, data.EMPTY_SET, data.EMPTY_SET, [])
+    meta = data.new_metadata("<conversions>", -1)
+    narration = "Conversion for {}".format(conversion_balance)
+    conversion_entry = Transaction(
+        meta,
+        last_date,
+        flags.FLAG_CONVERSIONS,
+        None,
+        narration,
+        data.EMPTY_SET,
+        data.EMPTY_SET,
+        [],
+    )
     for position in conversion_cost_balance.get_positions():
         # Important note: Set the cost to zero here to maintain the balance
         # invariant. (This is the only single place we cheat on the balance rule
@@ -504,8 +575,8 @@ def conversions(entries, conversion_account, conversion_currency, date=None):
         price = amount.Amount(ZERO, conversion_currency)
         neg_pos = -position
         conversion_entry.postings.append(
-            data.Posting(conversion_account, neg_pos.units, neg_pos.cost,
-                         price, None, None))
+            data.Posting(conversion_account, neg_pos.units, neg_pos.cost, price, None, None)
+        )
 
     # Make a copy of the list of entries and insert the new transaction into it.
     new_entries = list(entries)
@@ -514,7 +585,7 @@ def conversions(entries, conversion_account, conversion_currency, date=None):
     return new_entries
 
 
-def truncate(entries, date):
+def truncate(entries: Directives, date: datetime.date) -> Directives:
     """Filter out all the entries at and after date. Returns a new list of entries.
 
     Args:
@@ -523,14 +594,20 @@ def truncate(entries, date):
     Returns:
       A truncated list of directives.
     """
-    index = bisect_key.bisect_left_with_key(entries, date,
-                                            key=lambda entry: entry.date)
+    index = bisect_key.bisect_left_with_key(entries, date, key=lambda entry: entry.date)
     return entries[:index]
 
 
-def create_entries_from_balances(balances, date, source_account, direction,
-                                 meta, flag, narration_template):
-    """"Create a list of entries from a dict of balances.
+def create_entries_from_balances(
+    balances: dict[Account, inventory.Inventory],
+    date: datetime.date,
+    source_account: Account,
+    direction: bool,
+    meta: data.Meta,
+    flag: data.Flag,
+    narration_template: str,
+) -> Directives:
+    """ "Create a list of entries from a dict of balances.
 
     This method creates a list of new entries to transfer the amounts in the
     'balances' dict to/from another account specified in 'source_account'.
@@ -555,9 +632,8 @@ def create_entries_from_balances(balances, date, source_account, direction,
     Returns:
       A list of newly synthesizes Transaction entries.
     """
-    new_entries = []
+    new_entries: Directives = []
     for account, account_balance in sorted(balances.items()):
-
         # Don't create new entries where there is no balance.
         if account_balance.is_empty():
             continue
@@ -567,16 +643,17 @@ def create_entries_from_balances(balances, date, source_account, direction,
         if not direction:
             account_balance = -account_balance
 
-        postings = []
+        postings: list[data.Posting] = []
         new_entry = Transaction(
-            meta, date, flag, None, narration, data.EMPTY_SET, data.EMPTY_SET, postings)
+            meta, date, flag, None, narration, data.EMPTY_SET, data.EMPTY_SET, postings
+        )
 
         for position in account_balance.get_positions():
-            postings.append(data.Posting(account, position.units, position.cost,
-                                         None, None, None))
+            postings.append(
+                data.Posting(account, position.units, position.cost, None, None, None)
+            )
             cost = -convert.get_cost(position)
-            postings.append(data.Posting(source_account, cost, None,
-                                         None, None, None))
+            postings.append(data.Posting(source_account, cost, None, None, None, None))
 
         new_entries.append(new_entry)
 
@@ -585,7 +662,11 @@ def create_entries_from_balances(balances, date, source_account, direction,
 
 # TODO(blais): Reconcile this with beancount.core.realization.realize() {2196104406ab}.
 # TODO(blais): This should be generalized to any type of key, i.e., provide a key func.
-def balance_by_account(entries, date=None, compress_unbooked=False):
+def balance_by_account(
+    entries: Directives,
+    date: datetime.date | None = None,
+    compress_unbooked: bool = False,
+) -> tuple[dict[Account, inventory.Inventory], int]:
     """Sum up the balance per account for all entries strictly before 'date'.
 
     Args:
@@ -605,7 +686,9 @@ def balance_by_account(entries, date=None, compress_unbooked=False):
       cutoff date, an index one beyond the last entry is returned.
 
     """
-    balances = collections.defaultdict(inventory.Inventory)
+    balances: dict[Account, inventory.Inventory] = collections.defaultdict(
+        inventory.Inventory
+    )
     for index, entry in enumerate(entries):
         if date and entry.date >= date:
             break
@@ -647,7 +730,7 @@ def balance_by_account(entries, date=None, compress_unbooked=False):
     return balances, index
 
 
-def get_open_entries(entries, date):
+def get_open_entries(entries: Directives, date: datetime.date) -> list[Open]:
     """Gather the list of active Open entries at date.
 
     This returns the list of Open entries that have not been closed at the given
@@ -660,7 +743,7 @@ def get_open_entries(entries, date):
     Returns:
       A list of Open directives.
     """
-    open_entries = {}
+    open_entries: dict[Account, tuple[int, Open]] = {}
     for index, entry in enumerate(entries):
         if date is not None and entry.date >= date:
             break
