@@ -6,7 +6,6 @@ __copyright__ = "Copyright (C) 2015-2017, 2019-2022, 2024  Martin Blais"
 __license__ = "GNU GPLv2"
 
 from decimal import Decimal
-from typing import TYPE_CHECKING
 from typing import NamedTuple
 
 from beancount.core import convert
@@ -18,14 +17,7 @@ from beancount.core.data import Booking
 from beancount.core.data import Directive
 from beancount.core.data import Meta
 from beancount.core.number import ZERO
-
-if TYPE_CHECKING:
-    from decimal import Decimal
-
-    from beancount.core.position import Cost
-
-if TYPE_CHECKING:
-    from decimal import Decimal
+from beancount.core.position import Cost
 
 
 class AmbiguousMatchError(NamedTuple):
