@@ -5,14 +5,12 @@ we may want to add more tests here, just calling each method directly and
 covering all the possible branches.
 """
 
-__copyright__ = "Copyright (C) 2017  Martin Blais"
+__copyright__ = "Copyright (C) 2017, 2019, 2024  Martin Blais"
 __license__ = "GNU GPLv2"
 
 import unittest
 
-# pylint: disable=unused-import
-from beancount.parser import booking_method as bm
+from beancount.parser import booking_method as bm  # noqa: F401
 
-
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
