@@ -1,15 +1,14 @@
-__copyright__ = "Copyright (C) 2015-2017  Martin Blais"
+__copyright__ = "Copyright (C) 2015-2017, 2019-2020, 2024  Martin Blais"
 __license__ = "GNU GPLv2"
 
 
 import unittest
 
-from beancount.parser import hashsrc
 from beancount.parser import _parser
+from beancount.parser import hashsrc
 
 
 class TestHashSource(unittest.TestCase):
-
     def test_hash_parser_source_files(self):
         source_hash = hashsrc.hash_parser_source_files()
         self.assertTrue(isinstance(source_hash, str))
@@ -20,5 +19,5 @@ class TestHashSource(unittest.TestCase):
         hashsrc.check_parser_source_files(_parser)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
