@@ -1,26 +1,27 @@
-__copyright__ = "Copyright (C) 2014-2016  Martin Blais"
+__copyright__ = "Copyright (C) 2014-2020, 2024-2025  Martin Blais"
 __license__ = "GNU GPLv2"
 
 import io
 import os
-from datetime import date
-import unittest
 import re
-import textwrap
 import tempfile
+import textwrap
+import unittest
+from datetime import date
+from decimal import Decimal
 
-from beancount.parser import printer
-from beancount.parser import cmptest
-from beancount.core import data
-from beancount.core import interpolate
-from beancount.utils import test_utils
 from beancount import loader
+from beancount.core import data
+from beancount.core.amount import Amount
+from beancount.ops.balance import BalanceError
+from beancount.parser import cmptest
+from beancount.parser import printer
+from beancount.utils import test_utils
 
+META = data.new_metadata("beancount/core/testing.beancount", 12345)
 
-META = data.new_metadata('beancount/core/testing.beancount', 12345)
 
 class TestPrinter(unittest.TestCase):
-
     def test_methods_coverage(self):
         for klass in data.ALL_DIRECTIVES:
             self.assertTrue(hasattr(printer.EntryPrinter, klass.__name__))
@@ -28,12 +29,19 @@ class TestPrinter(unittest.TestCase):
     def test_render_source(self):
         source_str = printer.render_source(META)
         self.assertTrue(isinstance(source_str, str))
-        self.assertRegex(source_str, '12345')
-        self.assertRegex(source_str, META['filename'])
+        self.assertRegex(source_str, "12345")
+        self.assertRegex(source_str, META["filename"])
 
     def test_format_and_print_error(self):
-        entry = data.Open(META, date(2014, 1, 15), 'Assets:Bank:Checking', [], None)
-        error = interpolate.BalanceError(META, "Example balance error", entry)
+        entry = data.Balance(
+            META,
+            date(2014, 1, 15),
+            "Assets:Bank:Checking",
+            Amount(Decimal("0"), "USD"),
+            None,
+            None,
+        )
+        error = BalanceError(META, "Example balance error", entry)
         error_str = printer.format_error(error)
         self.assertTrue(isinstance(error_str, str))
 
@@ -47,7 +55,6 @@ class TestPrinter(unittest.TestCase):
 
 
 class TestEntryPrinter(cmptest.TestCase):
-
     def assertRoundTrip(self, entries1, errors1):
         self.assertFalse(errors1)
 
@@ -72,8 +79,7 @@ class TestEntryPrinter(cmptest.TestCase):
         # Compare the two output texts.
         self.assertEqual(oss2.getvalue(), oss1.getvalue())
 
-    def assertRoundTripViaRealFile(self, entries1, errors1,
-                                   test_write_source=True):
+    def assertRoundTripViaRealFile(self, entries1, errors1, test_write_source=True):
         """
         The same as assertRoundTrip, but the 1st time saves ledger in string
         format to a real file as an opposite to io.StringIO().
@@ -91,15 +97,16 @@ class TestEntryPrinter(cmptest.TestCase):
         # Contex manager can be used as of python 3.12
         # see https://github.com/python/cpython/issues/58451
         # https://github.com/beancount/beancount/issues/222
-        oss1 = tempfile.NamedTemporaryFile('w', suffix='.beancount',
-                                           delete=False)
+        oss1 = tempfile.NamedTemporaryFile(
+            "w", suffix=".beancount", delete=False, encoding="utf-8"
+        )
 
         oss1.write('option "plugin_processing_mode" "raw"\n')
         printer.print_entries(entries1, file=oss1)
 
         oss1.close()
 
-        with open(oss1.name, "r") as file:
+        with open(oss1.name, "r", encoding="utf-8") as file:
             oss1_value = file.read()
 
         # entries2 will contain information about filename and line number in
@@ -143,33 +150,32 @@ class TestEntryPrinter(cmptest.TestCase):
         ORIGINAL_LEDGER = textwrap.dedent("""\
         2014-01-01 open Assets:Account1
         2014-01-01 open Assets:Cash
-        
+
         2014-06-08 *
           Assets:Account1       111.00 BEAN
           Assets:Cash          -111.00 BEAN
         """)
 
-        # note:this multistring contains some training white spaces
         EXPECTED_OUTPUT_LEDGER_TEMPL = textwrap.dedent("""
-        ; source: __path_to_file__:1:      
+        ; source: __path_to_file__:1:
         2014-01-01 open Assets:Account1
-        
-        ; source: __path_to_file__:2:      
+
+        ; source: __path_to_file__:2:
         2014-01-01 open Assets:Cash
-        
-        ; source: __path_to_file__:4:      
-        2014-06-08 * 
+
+        ; source: __path_to_file__:4:
+        2014-06-08 *
           Assets:Account1   111.00 BEAN
           Assets:Cash      -111.00 BEAN
         """)
 
-
         # Not using context manager to make this test compatible with Windows
         # Contex manager can be used as of python 3.12
         # see https://github.com/python/cpython/issues/58451
         # https://github.com/beancount/beancount/issues/222
-        oss1 = tempfile.NamedTemporaryFile('w', suffix='.beancount',
-                                           delete=False)
+        oss1 = tempfile.NamedTemporaryFile(
+            "w", suffix=".beancount", delete=False, encoding="utf-8"
+        )
         oss1.write(ORIGINAL_LEDGER)
         oss1.close()
         # entries2 will contain the file name and line number in metadata
@@ -177,16 +183,20 @@ class TestEntryPrinter(cmptest.TestCase):
         self.assertFalse(errors)
 
         expected_output_ledger = EXPECTED_OUTPUT_LEDGER_TEMPL.replace(
-            '__path_to_file__',oss1.name)
+            "__path_to_file__", oss1.name
+        ).splitlines()
 
-        # Print out those reparsed and parse them back in.
+        # Print ledger with the source location information.
         oss2 = io.StringIO()
-        # Getting original ledger but with the source location information
         printer.print_entries(entries2, file=oss2, write_source=True)
+        oss2.seek(0)
 
-        self.maxDiff=1000
-        self.assertEqual(expected_output_ledger, oss2.getvalue())
+        # Get printed lines. Strip trailing whitespace to allow the
+        # expected output to do not contain trailing whitespace and
+        # appease linters.
+        printed = [line.rstrip() for line in oss2.readlines()]
 
+        self.assertEqual(expected_output_ledger, printed)
 
     @loader.load_doc()
     def test_Transaction(self, entries, errors, __):
@@ -235,7 +245,7 @@ class TestEntryPrinter(cmptest.TestCase):
           Assets:Account1         1 USD @ 0 OTHER
           Assets:Account2         1 CAD @ 0 OTHER
 
-        2014-06-10 * "Entry with escaped \\"symbols\\" \\ \\r \\n"
+        2014-06-10 * "Entry with escaped \\"quotes\\""
           Assets:Account1       111.00 BEAN
           Assets:Cash          -111.00 BEAN
 
@@ -244,7 +254,7 @@ class TestEntryPrinter(cmptest.TestCase):
         with self.subTest("RoundTrip test via StringIO"):
             self.assertRoundTrip(entries, errors)
 
-        #TODO: This test fails on Windows for the entry with escaped symbols
+        # TODO: This test fails on Windows for the entry with escaped symbols
         with self.subTest("RoundTrip test via real file"):
             self.assertRoundTripViaRealFile(entries, errors)
 
@@ -290,18 +300,36 @@ class TestEntryPrinter(cmptest.TestCase):
         with self.subTest("RoundTrip test via real file"):
             self.assertRoundTripViaRealFile(entries, errors)
 
-    @loader.load_doc()
-    def test_Document(self, entries, errors, __):
-        # pylint: disable=line-too-long
-        """
+    def test_Document(self):
+        # The beancount parser processes escaped characters in all strings,
+        # including the file path in the ``document`` directive.  Windows uses
+        # backslashes as file path separator character.  Unless these are
+        # escaped, the path separators are threated as the beginning of an
+        # escape sequence by the parser, producing the wrong result.
+        #
+        # The path separator characters can be escaped as double backslashes.
+        # However ``beancount.parser.print_entries()`` does not do that,
+        # breaking the round-trip test.  To change ``print_entries()`` to escape
+        # special characters would be an incompatible change.
+        #
+        # The solution could be to use a simple file name in the test, however,
+        # the beancount loader transforms all relative paths into absolute
+        # paths, introducing path separator characters.  Windows also accepts
+        # forward slashes as path separators, therefore, the solution is to
+        # craft the test to use absolute paths with forward slashes on all
+        # platforms.
+        path = os.path.join(os.path.dirname(__file__), "document.pdf").replace("\\", "/")
+
+        ledger = textwrap.dedent("""\
         option "plugin_processing_mode" "raw"
         2014-06-01 open Assets:Account1
-        2014-06-08 document Assets:Account1 "/path/to/document.pdf"
-        2014-06-08 document Assets:Account1 "path/to/document.csv"
-        2014-06-08 document Assets:Account1 "path/to/document2.csv" #tag1 #tag2 ^link1 ^link2
-        2014-06-08 document Assets:Account1 "path/to/document2.csv" #tag1
-        2014-06-08 document Assets:Account1 "path/to/document2.csv" ^link1
-        """
+        2014-06-08 document Assets:Account1 "{path}"
+        2014-06-08 document Assets:Account1 "{path}" #tag1 #tag2 ^link1 ^link2
+        2014-06-08 document Assets:Account1 "{path}" #tag1
+        2014-06-08 document Assets:Account1 "{path}" ^link1
+        """).format(path=path)
+        entries, errors, __ = loader.load_string(ledger)
+
         with self.subTest("RoundTrip test via StringIO"):
             self.assertRoundTrip(entries, errors)
 
@@ -384,14 +412,13 @@ class TestEntryPrinter(cmptest.TestCase):
             self.assertRoundTripViaRealFile(entries, errors)
 
     def test_metadata(self):
-        meta = data.new_metadata('beancount/core/testing.beancount', 12345)
-        meta['something'] = r'a"\c'
+        meta = data.new_metadata("beancount/core/testing.beancount", 12345)
+        meta["something"] = r'a"\c'
         oss = io.StringIO()
         printer.EntryPrinter().write_metadata(meta, oss)
         self.assertEqual('  something: "a\\"\\\\c"\n', oss.getvalue())
 
 
-
 def characterize_spaces(text):
     """Classify each line to a particular type.
 
@@ -402,14 +429,14 @@ def characterize_spaces(text):
     """
     lines = []
     for line in text.splitlines():
-        if re.match(r'\d\d\d\d-\d\d-\d\d open', line):
-            linecls = 'open'
-        elif re.match(r'\d\d\d\d-\d\d-\d\d price', line):
-            linecls = 'price'
-        elif re.match(r'\d\d\d\d-\d\d-\d\d', line):
-            linecls = 'txn'
-        elif re.match(r'[ \t]$', line):
-            linecls = 'empty'
+        if re.match(r"\d\d\d\d-\d\d-\d\d open", line):
+            linecls = "open"
+        elif re.match(r"\d\d\d\d-\d\d-\d\d price", line):
+            linecls = "price"
+        elif re.match(r"\d\d\d\d-\d\d-\d\d", line):
+            linecls = "txn"
+        elif re.match(r"[ \t]$", line):
+            linecls = "empty"
         else:
             linecls = None
         lines.append(linecls)
@@ -417,7 +444,6 @@ def characterize_spaces(text):
 
 
 class TestPrinterSpacing(unittest.TestCase):
-
     maxDiff = 8192
 
     def test_interline_spacing(self):
@@ -456,7 +482,6 @@ class TestPrinterSpacing(unittest.TestCase):
 
 
 class TestDisplayContext(test_utils.TestCase):
-
     maxDiff = 2048
 
     @loader.load_doc()
@@ -479,7 +504,7 @@ class TestDisplayContext(test_utils.TestCase):
           Assets:Cash       -4444.4444 FP4
           Assets:Cash     -55555.55555 FP5
         """
-        dcontext = options_map['dcontext']
+        dcontext = options_map["dcontext"]
         oss = io.StringIO()
         printer.print_entries(entries, dcontext, file=oss)
 
@@ -506,29 +531,33 @@ class TestDisplayContext(test_utils.TestCase):
 
 
 class TestPrinterAlignment(test_utils.TestCase):
-
     maxDiff = None
 
     def test_align_position_strings(self):
-        aligned_strings, width = printer.align_position_strings([
-            '45 HOOL {504.30 USD}',
-            '4 HOOL {504.30 USD / 2014-11-11}',
-            '9.9505 USD',
-            '',
-            '-22473.32 CAD @ 1.10 USD',
-            'UNKNOWN',
-            '76400.203',
-        ])
+        aligned_strings, width = printer.align_position_strings(
+            [
+                "45 HOOL {504.30 USD}",
+                "4 HOOL {504.30 USD / 2014-11-11}",
+                "9.9505 USD",
+                "",
+                "-22473.32 CAD @ 1.10 USD",
+                "UNKNOWN",
+                "76400.203",
+            ]
+        )
         self.assertEqual(40, width)
-        self.assertEqual([
-            '       45 HOOL {504.30 USD}             ',
-            '        4 HOOL {504.30 USD / 2014-11-11}',
-            '   9.9505 USD                           ',
-            '                                        ',
-            '-22473.32 CAD @ 1.10 USD                ',
-            'UNKNOWN                                 ',
-            '76400.203                               ',
-            ], aligned_strings)
+        self.assertEqual(
+            [
+                "       45 HOOL {504.30 USD}             ",
+                "        4 HOOL {504.30 USD / 2014-11-11}",
+                "   9.9505 USD                           ",
+                "                                        ",
+                "-22473.32 CAD @ 1.10 USD                ",
+                "UNKNOWN                                 ",
+                "76400.203                               ",
+            ],
+            aligned_strings,
+        )
 
     @loader.load_doc()
     def test_align(self, entries, errors, options_map):
@@ -540,7 +569,7 @@ class TestPrinterAlignment(test_utils.TestCase):
           Expenses:Commissions  9.9505 USD
           Expenses:Commissions  -20009.9505 USD
         """
-        dcontext = options_map['dcontext']
+        dcontext = options_map["dcontext"]
         oss = io.StringIO()
         printer.print_entries(entries, dcontext, file=oss)
         expected_str = textwrap.dedent("""\
@@ -563,7 +592,7 @@ class TestPrinterAlignment(test_utils.TestCase):
           Expenses:Commissions  9.9505 USD
           Expenses:Commissions  -20009.9505 USD
         """
-        dcontext = options_map['dcontext']
+        dcontext = options_map["dcontext"]
         oss = io.StringIO()
         eprinter = printer.EntryPrinter(dcontext, min_width_account=40)
         oss.write(eprinter(entries[1]))
@@ -589,7 +618,7 @@ class TestPrinterAlignment(test_utils.TestCase):
           Assets:US:Investments:Cash   -22473.32 CAD @ 1.10 USD
         """
         self.assertFalse(errors)
-        dcontext = options_map['dcontext']
+        dcontext = options_map["dcontext"]
 
         # oss = io.StringIO()
         # printer.print_entries(entries, dcontext, render_weights=False, file=oss)
@@ -623,7 +652,6 @@ class TestPrinterAlignment(test_utils.TestCase):
 
 
 class TestPrinterMisc(test_utils.TestCase):
-
     @loader.load_doc(expect_errors=True)
     def test_no_valid_account(self, entries, errors, options_map):
         """
@@ -697,7 +725,7 @@ class TestPrinterMisc(test_utils.TestCase):
         self.assertFalse(errors)
         oss = io.StringIO()
         printer.print_entries(entries, file=oss)
-        self.assertRegex(oss.getvalue(), '0.0000000000000000000000001 DKK')
+        self.assertRegex(oss.getvalue(), "0.0000000000000000000000001 DKK")
 
     def test_render_missing(self):
         # We want to make sure we never render with scientific notation.
@@ -728,8 +756,8 @@ class TestPrinterMisc(test_utils.TestCase):
         """)
         entries, errors, options_map = loader.load_string(input_string)
         self.assertFalse(errors)
-        self.assertIs(entries[-1].postings[-1].meta['foo'], None)
+        self.assertIs(entries[-1].postings[-1].meta["foo"], None)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
