@@ -3,24 +3,14 @@
 Note: This really ought to be an enhancement to Python itself. I should bother
 adding this in eventually.
 """
-__copyright__ = "Copyright (C) 2016  Martin Blais"
+
+__copyright__ = "Copyright (C) 2016-2018, 2020, 2022-2024  Martin Blais"
 __license__ = "GNU GPLv2"
 
-import collections
-
-
-class DefaultDictWithKey(collections.defaultdict):
-    """A version of defaultdict whose factory accepts the key as an argument.
-    Note: collections.defaultdict would be improved by supporting this directly,
-    this is a common occurrence.
-    """
-    def __missing__(self, key):
-        self[key] = value = self.default_factory(key)  # pylint: disable=not-callable
-        return value
-
 
 NOTFOUND = object()
 
+
 class ImmutableDictWithDefault(dict):
     """An immutable dict which returns a default value for missing keys.
 
@@ -28,6 +18,7 @@ class ImmutableDictWithDefault(dict):
     value when one is materialized (from a missing fetch), and furthermore, the
     set method is make unavailable to prevent mutation beyond construction.
     """
+
     def __init__(self, *args, default=None):
         super().__init__(*args)
         self.default = default
@@ -43,7 +34,7 @@ class ImmutableDictWithDefault(dict):
         return value
 
     def get(self, key, _=None):
-        return self.__getitem__(key)  # pylint: disable=unnecessary-dunder-call
+        return self.__getitem__(key)
 
     # The next three methods are present in order to support pickling. Note that
     # because this class is a specialization of dict, and that dict has a
