@@ -1,6 +1,8 @@
-"""Support utilities for testing scripts.
-"""
-__copyright__ = "Copyright (C) 2014-2016  Martin Blais"
+"""Support utilities for testing scripts."""
+
+from __future__ import annotations
+
+__copyright__ = "Copyright (C) 2008, 2013-2024  Martin Blais"
 __license__ = "GNU GPLv2"
 
 import builtins
@@ -15,8 +17,9 @@ import sys
 import tempfile
 import textwrap
 import unittest
-
 from os import path
+from pathlib import Path
+from typing import Generator
 
 import click.testing
 
@@ -43,7 +46,7 @@ def find_repository_root(filename=None):
     if match:
         return match.group(1)
 
-    while not path.exists(path.join(filename, 'pyproject.toml')):
+    while not path.exists(path.join(filename, "pyproject.toml")):
         prev_filename = filename
         filename = path.dirname(filename)
         if prev_filename == filename:
@@ -68,12 +71,28 @@ def subprocess_env():
     """
     # Ensure we have locations to invoke our Python executable and our
     # runnable binaries in the test environment to run subprocesses.
-    binpath = ':'.join([
-        path.dirname(sys.executable),
-        path.join(find_repository_root(__file__), 'bin'),
-        os.environ.get('PATH', '').strip(':')]).strip(':')
-    return {'PATH': binpath,
-            'PYTHONPATH': find_python_lib()}
+    binpath = ":".join(
+        [
+            path.dirname(sys.executable),
+            path.join(find_repository_root(__file__), "bin"),
+            os.environ.get("PATH", "").strip(":"),
+        ]
+    ).strip(":")
+    return {"PATH": binpath, "PYTHONPATH": find_python_lib()}
+
+
+@contextlib.contextmanager
+def temp_file(prefix: str = "", suffix: str = ".txt") -> Generator[Path, None, None]:
+    """A context manager that return a filepath inside inside a temporary directory and
+    deletes this directory unconditionally once done.
+
+    This utils exists because `NamedTemporaryFile` can't be re-opened on win32.
+
+    Yields:
+      A string, the name of the temporary directory created.
+    """
+    with tempfile.TemporaryDirectory(prefix="beancount-test-tmpdir.") as p:
+        yield Path(p, prefix + "-temp_file-" + suffix)
 
 
 @contextlib.contextmanager
@@ -114,8 +133,10 @@ def create_temporary_files(root, contents_map):
         filename = path.join(root, relative_filename)
         os.makedirs(path.dirname(filename), exist_ok=True)
 
-        clean_contents = textwrap.dedent(contents.replace('{root}', root))
-        with open(filename, 'w') as f:
+        clean_contents = textwrap.dedent(
+            contents.replace("{root}", root.replace("\\", r"\\"))
+        )
+        with open(filename, "w", encoding="utf-8") as f:
             f.write(clean_contents)
 
 
@@ -130,7 +151,7 @@ def capture(*attributes):
       A StringIO string accumulator.
     """
     if not attributes:
-        attributes = 'stdout'
+        attributes = "stdout"
     elif len(attributes) == 1:
         attributes = attributes[0]
     return patch(sys, attributes, io.StringIO)
@@ -168,28 +189,35 @@ def patch(obj, attributes, replacement_type):
         setattr(obj, attribute, saved_attr)
 
 
-def docfile(function, **kwargs):
+def docfile(
+    function,
+    contents: str | None = None,
+    prefix: str = "",
+    suffix: str = ".beancount",
+    encoding: str = "utf-8",
+):
     """A decorator that write the function's docstring to a temporary file
     and calls the decorated function with the temporary filename.  This is
     useful for writing tests.
 
     Args:
       function: A function to decorate.
+      contents: file content, default to function.__doc__
+      prefix: prefix of filename
+      suffix: suffix of filename
+      encoding: encoding of file content
     Returns:
       The decorated function.
     """
-    contents = kwargs.pop('contents', None)
 
     @functools.wraps(function)
     def new_function(self):
-        allowed = ('buffering', 'encoding', 'newline', 'dir', 'prefix', 'suffix')
-        if any(key not in allowed for key in kwargs):
-            raise ValueError("Invalid kwarg to docfile_extra")
-        with tempfile.NamedTemporaryFile('w', **kwargs) as file:
-            text = contents or function.__doc__
-            file.write(textwrap.dedent(text))
-            file.flush()
-            return function(self, file.name)
+        with temp_file(suffix=suffix, prefix=prefix) as file:
+            file.write_text(
+                textwrap.dedent(contents or function.__doc__), encoding=encoding
+            )
+            return function(self, str(file))
+
     new_function.__doc__ = None
     return new_function
 
@@ -217,16 +245,15 @@ def search_words(words, line):
     """
     if isinstance(words, str):
         words = words.split()
-    return re.search('.*'.join(r'\b{}\b'.format(word) for word in words), line)
+    return re.search(".*".join(r"\b{}\b".format(word) for word in words), line)
 
 
 class TestTempdirMixin:
-
     def setUp(self):
         super().setUp()
         # Create a temporary directory.
         self.prefix = self.__class__.__name__
-        self.tempdir = tempfile.mkdtemp(prefix='{}.'.format(self.prefix))
+        self.tempdir = tempfile.mkdtemp(prefix="{}.".format(self.prefix))
 
     def tearDown(self):
         super().tearDown()
@@ -242,7 +269,7 @@ class TmpFilesTestBase(unittest.TestCase):
 
     # The list of strings, documents to create.
     # Filenames ending with a '/' will be created as directories.
-    TEST_DOCUMENTS = None
+    TEST_DOCUMENTS: list[str]
 
     def setUp(self):
         self.tempdir, self.root = self.create_file_hierarchy(self.TEST_DOCUMENTS)
@@ -251,7 +278,7 @@ class TmpFilesTestBase(unittest.TestCase):
         shutil.rmtree(self.tempdir, ignore_errors=True)
 
     @staticmethod
-    def create_file_hierarchy(test_files, subdir='root'):
+    def create_file_hierarchy(test_files, subdir="root"):
         """A test utility that creates a hierarchy of files.
 
         Args:
@@ -268,18 +295,18 @@ class TmpFilesTestBase(unittest.TestCase):
         root = path.join(tempdir, subdir)
         for filename in test_files:
             abs_filename = path.join(tempdir, filename)
-            if filename.endswith('/'):
+            if filename.endswith("/"):
                 os.makedirs(abs_filename)
             else:
                 parent_dir = path.dirname(abs_filename)
                 if not path.exists(parent_dir):
                     os.makedirs(parent_dir)
-                with open(abs_filename, 'w'): pass
+                with open(abs_filename, "w", encoding="utf-8"):
+                    pass
         return tempdir, root
 
 
 class TestCase(unittest.TestCase):
-
     def assertLines(self, text1, text2, message=None):
         """Compare the lines of text1 and text2, ignoring whitespace.
 
@@ -297,8 +324,8 @@ class TestCase(unittest.TestCase):
 
         # Compress all space longer than 4 spaces to exactly 4.
         # This affords us to be even looser.
-        lines1 = [re.sub('    [ \t]*', '    ', line) for line in lines1]
-        lines2 = [re.sub('    [ \t]*', '    ', line) for line in lines2]
+        lines1 = [re.sub("    [ \t]*", "    ", line) for line in lines1]
+        lines2 = [re.sub("    [ \t]*", "    ", line) for line in lines2]
         self.assertEqual(lines1, lines2, message)
 
     @contextlib.contextmanager
@@ -355,10 +382,12 @@ def make_failing_importer(*removed_module_names):
     Returns:
       A decorated test decorator.
     """
+
     def failing_import(name, *args, **kwargs):
         if name in removed_module_names:
             raise ImportError("Could not import {}".format(name))
         return builtins.__import__(name, *args, **kwargs)
+
     return failing_import
 
 
@@ -383,7 +412,8 @@ def environ(varname, newvalue):
 # This is an improvement onto what mock.call provides.
 # That has not the return value normally.
 # You can use this to build internal call interceptors.
-RCall = collections.namedtuple('RCall', 'args kwargs return_value')
+RCall = collections.namedtuple("RCall", "args kwargs return_value")
+
 
 def record(fun):
     """Decorates the function to intercept and record all calls and return values.
@@ -393,10 +423,12 @@ def record(fun):
     Returns:
       A wrapper function with a .calls attribute, a list of RCall instances.
     """
+
     @functools.wraps(fun)
     def wrapped(*args, **kw):
         return_value = fun(*args, **kw)
         wrapped.calls.append(RCall(args, kw, return_value))
         return return_value
+
     wrapped.calls = []
     return wrapped
